OC.L10N.register(
    "spreed",
    {
    "a conversation" : "en samtale",
    "(Duration %s)" : "(Varighed %s)",
    "You attended a call with {user1}" : "Du deltog i et opkald med {user1}",
    "_%n guest_::_%n guests_" : ["%n gæst","%n gæster"],
    "You attended a call with {user1} and {user2}" : "Du deltog i et opkald med {user1} og {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Du deltog i et opkald med {user1}, {user2} og {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Du deltog i et opkald med {user1}, {user2}, {user3} og {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Du deltog i et opkald med {user1}, {user2}, {user3}, {user4} og {user5}",
    "_%n other_::_%n others_" : ["%n andre","%n andre"],
    "{actor} invited you to {call}" : "{actor} inviterede dig til {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Du var inviteret til en <strong>samtale</strong> eller fik et <strong>opkald</strong>",
    "Talk" : "Snak",
    "Guest" : "Gæst",
    "Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Velkommen til Nextcloud Talk!\nI denne samtale finder du information om nye features tilgængelige i Nextcloud Talk.",
    "New in Talk 6" : "Nyt i Talk 6",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge og Safari kan nu benyttes til at deltage i lyd- og videosamtaler",
    "- One-to-one conversations are now persistent and can not be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- En-til-en-samtaler er nu vedvarende og kan ikke laves til gruppesamtaler ved en fejl længere. Derudover bliver samtaler ikke længere slettet automatisk når en af deltagerne forlader den. Samtalen slettes kun fra serveren hvis begge deltagere har forladt den",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Nu kan nu sende en notifikation til alle deltagere ved at skrive \"@all\" i chatten",
    "- With the \"arrow-up\" key you can repost your last message" : "- Ved at trykke på \"pil op\" kan du sende din sidste besked igen",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk understøtter nu kommandoer. Send \"/help\" som en chat-besked for at se om din administrator har konfigureret nogen",
    "- With projects you can create quick links between conversations, files and other items" : "- Med projekter kan du oprette hurtige links mellem samtaler, filer og andre objekter",
    "New in Talk 7" : "Nyt i Talk 7",
    "- You can now mention guests in the chat" : "- Du kan nu nævne gæster i samtalen",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Samtaler kan nu have en lobby. Dette giver mulighed for at moderatorer kan forbinde til samtalen for at forberede mødet, mens almindelige brugere og gæster må vente",
    "New in Talk 8" : "Nyt i Talk 8",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Du kan nu svare direkte på beskeder og dermed give andre brugere mere kontekst om hvad din besked handler om",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Søgninger efter samtaler og deltagere vil nu også filtrere dine eksisterende samtaler, hvilke gør det meget nemmere at finde tidligere samtaler",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Du kan nu tilføje brugerdefinerede brugergrupper til samtaler når cirkel-appen er installeret",
    "There are currently no commands available." : "Der er pt ingen kommandoer tilgængelige.",
    "The command does not exist" : "Kommandoen findes ikke",
    "An error occurred while running the command. Please ask an administrator to check the logs." : "Der opstod en fejl ved kørsel af kommandoen. Bed venligst en administrator om at kigge i logfilerne.",
    "Talk updates ✅" : "Talk-opdateringer ✅",
    "{actor} created the conversation" : "{actor} oprettede samtalen",
    "You created the conversation" : "Du oprettede samtalen",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Du omdøbte samtalen fra \"%1$s\" til \"%2$s\"",
    "{actor} started a call" : "{actor} startede et opkald",
    "You started a call" : "Du startede et opkald",
    "{actor} joined the call" : "{actor} deltog i opkaldet",
    "You joined the call" : "Du forbandt til opkaldet",
    "{actor} left the call" : "{actor} forlod opkaldet",
    "You left the call" : "Du forlod opkaldet",
    "{actor} unlocked the conversation" : "{actor} låste op for samtalen",
    "You unlocked the conversation" : "Du låste op for samtalen",
    "{actor} locked the conversation" : "{actor} låste samtalen",
    "You locked the conversation" : "Du låste samtalen",
    "The conversation is now open to everyone" : "Samtalen er nu åben for alle",
    "{actor} opened the conversation to everyone" : "{actor} åbnede samtalen for alle",
    "You opened the conversation to everyone" : "Du åbnede samtalen for alle",
    "{actor} restricted the conversation to moderators" : "{actor} begrænsede samtalen til moderatorer",
    "You restricted the conversation to moderators" : "Du begrænsede samtalen til moderatorer",
    "{actor} allowed guests" : "{actor} tillod gæster",
    "You allowed guests" : "Du tillod gæster",
    "{actor} disallowed guests" : "{actor} forbød gæster",
    "You disallowed guests" : "Du forbød gæster",
    "{actor} set a password" : "{actor} indstillede en adgangskode",
    "You set a password" : "Du indstillede en adgangskode",
    "{actor} removed the password" : "{actor} fjernede adgangskoden",
    "You removed the password" : "Du fjernede adgangskoden",
    "{actor} added {user}" : "{actor} tilføjede {user}",
    "You joined the conversation" : "Du forbandt til samtalen",
    "{actor} joined the conversation" : "{actor} forbandt til samtalen",
    "You added {user}" : "Du tilføjede {user}",
    "{actor} added you" : "{actor} tilføjede dig",
    "You left the conversation" : "Du forlod samtalen",
    "{actor} left the conversation" : "{actor} forlod samtalen",
    "{actor} removed {user}" : "{actor} fjernede {user}",
    "You removed {user}" : "Du fjernede {user}",
    "{actor} removed you" : "{actor} fjernede dig",
    "{actor} promoted {user} to moderator" : "{actor} forfremmede {user} til moderator",
    "You promoted {user} to moderator" : "Du forfremmede {user} til moderator",
    "{actor} promoted you to moderator" : "{actor} forfremmede dig til moderator",
    "{actor} demoted {user} from moderator" : "{actor} degraderede {user} fra moderator",
    "You demoted {user} from moderator" : "Du degraderede {user} fra moderator",
    "{actor} demoted you from moderator" : "{actor} degraderede dig fra moderator",
    "{actor} shared a file which is no longer available" : "{actor} delte en fil, der ikke længere er tilgængelig",
    "You shared a file which is no longer available" : "Du delte en fil, der ikke længere er tilgængelig",
    "%s (guest)" : "%s (gæst)",
    "_Call with %n guest (Duration {duration})_::_Call with %n guests (Duration {duration})_" : ["Opkald med 1 gæst (Varighed {duration})","Opkald med %n gæster (Varighed {duration})"],
    "Call with {user1} and {user2} (Duration {duration})" : "Opkald med {user1} og {user2} (Varighed {duration})",
    "Call with {user1}, {user2} and {user3} (Duration {duration})" : "Opkald med {user1}, {user2} og {user3} (Varighed {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3} og {user4} (Varighed {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "Opkald med {user1}, {user2}, {user3}, {user4} og {user5} (Varighed {duration})",
    "Talk to %s" : "Tal med %s",
    "File is not shared, or shared but not with the user" : "Filen er ikke delt, eller den er delt men ikke med brugeren",
    "Write to conversation" : "Skriv til samtale",
    "Writes event information into a conversation of your choice" : "Skriver begivenhedsinformation i en samtale du vælger",
    "%s invited you to a conversation." : "%s inviterede dig til en samtale",
    "You were invited to a conversation." : "Du blev inviteret til en samtale.",
    "Conversation invitation" : "Invitation til samtale",
    "Click the button below to join." : "Tryk på knappen nedenfor for at deltage.",
    "Join »%s«" : "Deltag i »%s«",
    "Password request: %s" : "Password-forespørgsel: %s",
    "Private conversation" : "Privat samtale",
    "Deleted user (%s)" : "Slettet bruger (%s)",
    "{user} sent you a private message" : "{user} sendte dig en privat besked",
    "{user} sent a message in conversation {call}" : "{user} sendte en besked i samtalen {call}",
    "A deleted user sent a message in conversation {call}" : "En slettet bruger sendte en besked i samtalen {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gæst) sendte en besked i samtalen {call}",
    "A guest sent a message in conversation {call}" : "En gæst sendte en besked i samtalen {call}",
    "{user} replied to your private message" : "{user} svarede på din private besked",
    "{user} replied to your message in conversation {call}" : "{user} svarede på din besked i samtalen {call}",
    "A deleted user replied to your message in conversation {call}" : "En slettet bruger svarede på din besked i samtalen {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gæst) svarede på din besked i samtalen {call}",
    "A guest replied to your message in conversation {call}" : "En gæst svarede på din besked i samtalen {call}",
    "{user} mentioned you in a private conversation" : "{user} omtalte dig i en privat samtale",
    "{user} mentioned you in conversation {call}" : "{user} omtalte dig i samtalen {call}",
    "A deleted user mentioned you in conversation {call}" : "En slettet bruger omtalte dig i samtalen {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gæst) omtalte dig i samtalen {call}",
    "A guest mentioned you in conversation {call}" : "En gæst omtalte dig i samtalen {call}",
    "View chat" : "Se chat",
    "{user} invited you to a private conversation" : "{user} inviterede dig til en privat samtale",
    "Join call" : "Deltag i opkaldet",
    "{user} invited you to a group conversation: {call}" : "{user} inviterede dig til en gruppesamtale: {call}",
    "Answer call" : "Besvar opkald",
    "{user} wants to talk with you" : "{user} vil gerne snakke med dig",
    "Call back" : "Ring tilbage",
    "You missed a call from {user}" : "Du missede et opkald fra {user}",
    "A group call has started in {call}" : "Et gruppeopkald er startet i {call}",
    "You missed a group call in {call}" : "Du missede en gruppesamtale i {call}",
    "{email} is requesting the password to access {file}" : "{email} anmoder om adgangskoden til {file}",
    "{email} tried to request the password to access {file}" : "{email} forsøgte at anmode om adgangskoden til {file}",
    "Someone is requesting the password to access {file}" : "Nogen beder om adgangskoden til {file}",
    "Someone tried to request the password to access {file}" : "Nogen forsøgte at bede om adgangskoden til {file}",
    "Open settings" : "Indstillinger",
    "Conversations" : "Samtaler",
    "Messages" : "Beskeder",
    "Andorra" : "Andorra",
    "Afghanistan" : "Afghanistan",
    "Albania" : "Albanien",
    "Armenia" : "Armenien",
    "Angola" : "Angola",
    "Argentina" : "Argentina",
    "Austria" : "Østrig",
    "Australia" : "Australien",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "Belgien",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarien",
    "Bahrain" : "Bahrain",
    "Bermuda" : "Bermuda",
    "Brazil" : "Brasilien",
    "Bahamas" : "Bahamas",
    "Canada" : "Canada",
    "Chile" : "Chile",
    "China" : "Kina",
    "Cuba" : "Cuba",
    "Germany" : "Tyskland",
    "Denmark" : "Danmark",
    "Algeria" : "Algeriet",
    "Ecuador" : "Ecuador",
    "Egypt" : "Egypten",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanien",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Faroe Islands" : "Færøerne",
    "France" : "Frankrig",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Grønland",
    "Guinea" : "Guinea",
    "Greece" : "Grækenland",
    "Guatemala" : "Guatemala",
    "Hong Kong" : "Hong Kong",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatien",
    "Haiti" : "Haiti",
    "Hungary" : "Ungarn",
    "Indonesia" : "Indonesien",
    "Ireland" : "Irland",
    "Israel" : "Israel",
    "India" : "Indien",
    "Iraq" : "Irak",
    "Iceland" : "Island",
    "Italy" : "Italien",
    "Jamaica" : "Jamaica",
    "Japan" : "Japan",
    "Kenya" : "Kenya",
    "Kuwait" : "Kuwait",
    "Liechtenstein" : "Liechtenstein",
    "Luxembourg" : "Luxembourg",
    "Montenegro" : "Montenegro",
    "Namibia" : "Namibia",
    "Norway" : "Norge",
    "Nepal" : "Nepal",
    "New Zealand" : "New Zealand",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Portugal" : "Portugal",
    "Qatar" : "Qatar",
    "Romania" : "Rumænien",
    "Rwanda" : "Rwanda",
    "Sudan" : "Sudan",
    "Sweden" : "Sverige",
    "Singapore" : "Singapore",
    "Slovenia" : "Slovenien",
    "Slovakia" : "Slovakiet",
    "Senegal" : "Senegal",
    "Somalia" : "Somalia",
    "Chad" : "Chad",
    "Thailand" : "Thailand",
    "Tunisia" : "Tunesien",
    "Turkey" : "Tyrkiet",
    "Ukraine" : "Ukraine",
    "Uganda" : "Uganda",
    "Samoa" : "Samoa",
    "Yemen" : "Yemen",
    "South Africa" : "Sydafrika",
    "Zimbabwe" : "Zimbabwe",
    "Invalid date, date format must be YYYY-MM-DD" : "Ugyldig dato. Brug formatet ÅÅÅ-MM-DD",
    "Conversation not found" : "Samtalen blev ikke fundet",
    "Path is already shared with this room" : "Stien er allerede delt med dette rum",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video- & lyd-samtaler over WebRTC",
    "Leave call" : "Forlad opkald",
    "Discuss this file" : "Diskuter denne fil",
    "Share this file with others to discuss it" : "Del denne fil med andre for at diskutere den",
    "Share this file" : "Del denne fil",
    "Join conversation" : "Gå med i samtale",
    "Request password" : "Anmod om adgangskode",
    "Error requesting the password." : "Der opstod en fejl ved anmodning om adgangskoden.",
    "This conversation has ended" : "Samtalen er slut",
    "Limit to groups" : "Begræns til grupper",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Når en eller flere grupper er valgt kan kun personer i de valgte grupper deltage i samtaler.",
    "Guests can still join public conversations." : "Gæster kan stadig deltage i offentlige samtaler.",
    "Users that can not use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Brugere som ikke længere kan bruge Talk vil stadig fremgå som deltagere i tidligere samtaler de har deltaget i, og deres chat-beskeder vil blive gemt.",
    "When a call has started, everyone with access to the conversation can join the call." : "Når et opkald er startet, kan alle som har adgang til samtalen deltage i opkaldet.",
    "Everyone" : "Alle",
    "Users and moderators" : "Brugere og moderatorer",
    "Moderators only" : "Kun moderatorer",
    "Save changes" : "Gem ændringer",
    "Saving …" : "Gemmer…",
    "Saved!" : "Gemt!",
    "None" : "Ingen",
    "User" : "ruger",
    "Disabled" : "Deaktiveret",
    "Moderators" : "Moderatorer",
    "Users" : "Brugere",
    "Commands" : "Kommandoer",
    "Beta" : "Beta",
    "Name" : "Navn",
    "Command" : "Kommando",
    "Script" : "Script",
    "Response to" : "Svar til",
    "Enabled for" : "Aktiveret for",
    "General settings" : "Generelle indstillinger",
    "Default notification settings" : "Standardindstillinger for notifikationer",
    "Default group notification" : "Standardindstillinger for gruppenotifikation",
    "Default group notification for new groups" : "Standardindstillinger for gruppenotifikation for nye grupper",
    "Integration into other apps" : "Integration med andre apps",
    "Allow conversations on files" : "Tillad samtaler om filer",
    "Allow conversations on public shares for files" : "Tillad samtaler om offentlige delinger af filer",
    "All messages" : "Alle beskeder",
    "@-mentions only" : "Kun når nævnt med @",
    "Off" : "Slået fra",
    "Language" : "Sprog",
    "Country" : "Land",
    "Status" : "Status",
    "Created at" : "Oprettet",
    "Pending" : "Afventer",
    "Error" : "Fejl",
    "Blocked" : "Blokeret",
    "Expired" : "Udløbet",
    "Validate SSL certificate" : "Godkend SSL certifikat",
    "Delete this server" : "Slet denne server",
    "Saved" : "Gemt",
    "Add a new server" : "Tilføj en ny server",
    "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver bør eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
    "Please note that calls with more than 4 participants without external signaling server, participants can experience connectivity issues and cause high load on participating devices." : "Observer at i opkald med mere end 4 deltagere uden en ekstern signaleringsserver, kan deltagerne opleve problemer med forbindelsen og det kan skabe høj belastning på deltagernes enheder.",
    "Don't warn about connectivity issues in calls with more than 4 participants" : "Vis ikke advarsel om forbindelsesproblemer i samtaler med mere end 4 deltagere",
    "Shared secret" : "Delt hemmelighed",
    "STUN server URL" : "STUN-server URL",
    "STUN servers" : "STUN-servere",
    "A STUN server is used to determine the public IP address of participants behind a router." : "En STUN-server bliver brugt til at bestemme den offentlige IP adresse for deltagerne bagved en router.",
    "TURN server URL" : "TURN server URL",
    "TURN server secret" : "TURN-server secret",
    "TURN server protocols" : "TURN server protokoller ",
    "UDP and TCP" : "UDP og TCP",
    "UDP only" : "kun UDP",
    "TCP only" : "kun TCP",
    "Test this server" : "Test denne server",
    "TURN servers" : "TURN-servere",
    "Copy link" : "Kopier link",
    "Waiting for others to join the call …" : "Venter på andre tilslutter sig opkaldet ...",
    "You can invite others in the participant tab of the sidebar" : "Du kan invitere andre i fanebladet \"deltagere\" i menuen i siden",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Du kan invitere andre i fanebladet \"deltagere\" i menuen i siden, eller dele dette link for at invitere andre!",
    "Share this link to invite others!" : "Del dette link for at invitere andre!",
    "Conversation link copied to clipboard." : "Samtalelink kopieret til udklipsholder",
    "The link could not be copied." : "Linket kunne ikke kopieres.",
    "Share whole screen" : "Del hele skærmen",
    "Share a single window" : "Del et vindue",
    "Show your screen" : "Vis din skærm",
    "Stop screensharing" : "Stop skærmdeling",
    "Dismiss" : "Afvis",
    "No audio" : "Ingen lyd",
    "Mute audio (m)" : "Slå lyden fra (m)",
    "Unmute audio (m)" : "Slå lyden til (m)",
    "Mute audio" : "Slå lyden fra",
    "No camera" : "Intet kamera",
    "Disable video (v)" : "Slå video fra (v)",
    "Enable video (v)" : "Slå video til (v)",
    "Enable video (v) - Your connection will be briefly interrupted when enabling the video for the first time" : "Aktiver video (v) - Forbindelsen forsvinder et øjeblik første gang du slår video til",
    "Disable video" : "Deaktiver video",
    "Enable video" : "Slå video til",
    "Screensharing options" : "Skærmdeling indstillinger",
    "Enable screensharing" : "Slå skærmdeling til",
    "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
    "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Skærmdeling virker kun med Firefox version 52 eller nyere.",
    "Screensharing extension is required to share your screen." : "En skærmdeling udvidelse er påkrævet for at dele din skærm.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Brug venligst en anden browser som Firefox og Chrome for at dele din skærm.",
    "An error occurred while starting screensharing." : "Der opstod en fejl da du prøvede at dele skærm.",
    "You have been muted by a moderator" : "Du er blevet sat på mute af en moderator",
    "You" : "Dig",
    "Show screen" : "Vis skærm",
    "Mute" : "Mute",
    "You need to be logged in to upload files" : "Du skal være logget ind for at kunne uploade filer",
    "Drop your files to upload" : "Drop dine filer for at uploade",
    "Call in progress" : "Opkald i gang",
    "Favorite" : "Foretrukken",
    "Chat notifications" : "Chat-notifikationer",
    "Leave conversation" : "Forlad samtale",
    "Delete conversation" : "Slet samtale",
    "Remove from favorites" : "Fjernet fra favoritter",
    "Add to favorites" : "Føj til favoritter",
    "You: {lastMessage}" : "Dig: {lastMessage}",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Do you really want to delete \"{displayName}\"?" : "Er du sikker på at du vil slette \"{displayName}\"?",
    "You need to promote a new moderator before you can leave the conversation." : "Du skal udnævne en ny moderator før du kan forlade samtalen.",
    "No matches" : "Ingen matches",
    "Loading" : "Indlæser",
    "No search results" : "Ingen søgeresultater",
    "Groups" : "Grupper",
    "Circles" : "Cirkler",
    "Settings" : "Indstillinger",
    "Groups and circles" : "Grupper og cirkler",
    "Other sources" : "Andre kilder",
    "Creating your conversation" : "Opret din samtale",
    "All set" : "Samtalen er klar",
    "Copy conversation link" : "Kopier samtalelink",
    "Error while creating the conversation" : "Fejl under oprettelse af samtalen",
    "Link copied to the clipboard!" : "Link kopieret til udklipsholderen!",
    "Create a new group conversation" : "Opret en ny gruppesamtale",
    "Password protect" : "Beskyt med adgangskode",
    "Add participants" : "Tilføj deltagere",
    "Back" : "Tilbage",
    "Create conversation" : "Opret samtale",
    "Close" : "Luk",
    "Choose a password" : "Vælg en adgangskode",
    "Search participants" : "Find deltagere",
    "An error occurred while performing the search" : "Der opstod en fejl under søgningen",
    "Conversation name" : "Samtalenavn",
    "Allow guests to join via link " : "Tillad gæster at deltage via link",
    "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
    "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du venter nu i lobbyen. Dette møde er planlagt til {startTime}",
    "Camera" : "Kamera",
    "Reply" : "Besvar",
    "Remove" : "Fjern",
    "[Unknown username]" : "[Ukendt brugernavn]",
    "Today" : "I dag",
    "Yesterday" : "I går",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Upload new files" : "Upload nye filer",
    "Share from Files" : "Del fra Filer",
    "Send message" : "Send besked",
    "File to share" : "Vælg fil til deling",
    "Write message, @ to mention someone …" : "Skriv besked, brug @ for at nævne en bruger ...",
    "Invalid path selected" : "Ugyldig filsti valgt",
    "Enabled" : "Aktiveret",
    "Save" : "Gem",
    "Password" : "Password",
    "API token" : "API nøgle",
    "Login" : "Login",
    "Nickname" : "Kaldenavn",
    "Client ID" : "Klient-ID",
    "moderator" : "moderator",
    "guest" : "Gæst",
    "Demote from moderator" : "Degrader fra moderator",
    "Promote to moderator" : "Forfrem til moderator",
    "Remove participant" : "Fjern deltager",
    "Add groups" : "Tilføj grupper",
    "Add emails" : "Tilføj emails",
    "Add circles" : "Tilføj cirkler",
    "Searching …" : "Søger ...",
    "No results" : "Ingen resultater",
    "Add users or groups" : "Add users or groups",
    "Add groups or circles" : "Tilføj grupper eller cirkler",
    "Add other sources" : "Tilføj andre kilder",
    "Participants" : "Deltagere",
    "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
    "Chat" : "Chat",
    "Display name: " : "Vist navn:",
    "Edit" : "Rediger",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Search" : "Søg",
    "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
    "Start call" : "Start opkald",
    "Go to file" : "Gå til fil",
    "Rename conversation" : "Omdøb samtale",
    "Share link" : "Del link",
    "Password protection" : "Adgangskodebeskyttelse",
    "Enter a password" : "Enter a password",
    "Enable lobby" : "Aktiver lobby",
    "Start time (optional)" : "Starttid (valgfri)",
    "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
    "Fullscreen (f)" : "Vis i fuldskærm (f)",
    "Grid view" : "Grid visning",
    "Send" : "Send",
    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
    "Start a conversation" : "Start en samtale",
    "Message without mention" : "Besked som ikke nævner nogen",
    "Mention myself" : "Nævn mig selv",
    "Mention room" : "Nævn rum",
    "The conversation does not exist" : "Samtalen findes ikke",
    "Join a conversation or start a new one!" : "Deltag i en samtale eller start en ny!",
    "Link to a conversation" : "Link til samtale",
    "Select conversation" : "Vælg samtale",
    "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
    "Error while sharing file" : "Fejl ved deling af fil",
    "Error while uploading file" : "Fejl ved upload af fil",
    "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked",
    "Default" : "Standard",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Det virker som om du snakker mens lyden er slået fra, slå den til hvis du vil have at andre skal høre dig",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dette tager lidt længere end forventet. Er medie-rettigheder allerede givet (eller nægtet)? Hvis ja så prøv at genstarte din browser, for lyd og video virker ikke lige nu",
    "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
    "Please move your setup to HTTPS" : "Flyt venligst din installation til HTTPS",
    "Access to microphone & camera was denied" : "Ingen adgang til mikrofon og kamera",
    "WebRTC is not supported in your browser" : "WebRTC er ikke undertøttet i din browser",
    "Please use a different browser like Firefox or Chrome" : "Benyt venligst en anden browser f.eks. Firefox eller Chrome",
    "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
    "This conversation is password-protected" : "Denne samtale er beskyttet af adgangskode",
    "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
    "Specify commands the users can use in chats" : "Definer kommandoer brugerne kan bruge i chats",
    "TURN server" : "TURN server",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
    "Signaling servers" : "Signaleringsservere",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
    "%s Talk on your mobile devices" : "%s Talk på dine mobilenheder",
    "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "No other people in this call" : "Ingen andre deltager i dette opkald",
    "Your screen" : "Din skærm",
    "Contacts" : "Kontakter",
    "Contacts, groups and circles" : "Kontakter, grupper og cirkler",
    "Contacts and groups" : "Kontakter og grupper",
    "Contacts and circles" : "Kontakter og cirkler",
    "Loading contacts" : "Henter kontakter",
    "Select participants" : "Vælg deltagere",
    "Search conversations or contacts" : "Søg efter samtaler og kontakter",
    "[Unknown user name]" : "[Ukendt brugernavn] ",
    "Search for more contacts" : "Søg efter flere kontakter",
    "Contacts loading" : "Henter kontakter",
    "Add participants to the conversation" : "Tilføj deltagere til samtalen",
    "Add contacts" : "Tilføj kontakter",
    "Add contacts, groups or circles" : "Tilføj kontakter, grupper eller cirkler",
    "Add contacts or groups" : "Tilføj kontakter eller grupper",
    "Add contacts or circles" : "Tilføj kontakter eller cirkler",
    "Guests" : "Gæster",
    "Webinar" : "Webinar",
    "Projects" : "Projekter",
    "Limit app usage to groups." : "Begræns app-brug til grupper.",
    "Start calls" : "Start opkald",
    "Who can start a call?" : "Hvem kan starte et opkald?",
    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
    "Please enter the password for this call" : "Indtast venligst password for dette opkald",
    "Password required" : "Password påkrævet",
    "Cancel" : "Annullér",
    "Submit" : "Indsend",
    "Signaling server URL" : "Signalserver URL",
    "This conversation is read only" : "Denne samtale er skrivebeskyttet",
    "Default location for attachments" : "Standard-lokation for vedhæftninger",
    "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger"
},
"nplurals=2; plural=(n != 1);");
